@@ -164,7 +164,7 @@ class Desktop(MethodsInterface):
                     tf.close()
         return True
 
-    def createUserDir(self, userName, uid, gid, userDir, mode=0700):
+    def createUserDir(self, userName, uid, gid, userDir, mode=0o700):
         """
         Create user directory with need uid and gid
         """
@@ -201,10 +201,10 @@ class Desktop(MethodsInterface):
         mountProfileDir = path.join(dirStart, ".%s" % dirEnd)
         mountRemoteProfileDir = path.join(dirStart, ".%s.remote" % dirEnd)
         with open("/proc/mounts") as f:
-            return filter(lambda x: x.startswith(homeDir) or
-                                    x.startswith(mountProfileDir) or
-                                    x.startswith(mountRemoteProfileDir),
-                          map(lambda x: x.split(" ")[1], f))
+            return [x for x in (y.split(" ")[1] for y in f) 
+                if x.startswith(homeDir) 
+                or x.startswith(mountProfileDir) 
+                or x.startswith(mountRemoteProfileDir)]
 
     def umountSleepPath(self, rpath):
         """
@@ -216,7 +216,7 @@ class Desktop(MethodsInterface):
         fuser_cmd = getProgPath("/bin/fuser")
         loops = getLoopFromPath(rpath)
         if loops:
-            setLoops = set(map(lambda x: x.partition('/dev/')[2], loops))
+            setLoops = set((x.partition('/dev/')[2] for x in loops))
             mdInfo = getMdRaidDevices()
             for k, v in mdInfo.items():
                 if setLoops & set(v):
@@ -335,17 +335,14 @@ class Desktop(MethodsInterface):
             if uid:
                 uid = int(uid)
             for i in range(0, postWaitTime):
-                if not filter(lambda x: "ksmserver" in x,
-                              getRunCommands(uid=uid)):
+                if not [x for x in getRunCommands(uid=uid) if "ksmserver" in x]:
                     break
                 time.sleep(1)
         time.sleep(1)
-        
-        if filter(lambda x: "xdm/xdm\x00--logout" in x,
-                  getRunCommands()):
+
+        if [x for x in getRunCommands() if "xdm/xdm\x00--logout" in x]:
             for i in range(0, waitTime):
-                if not filter(lambda x: "xdm/xdm\x00--logout" in x,
-                              getRunCommands()):
+                if not [x for x in getRunCommands() if "xdm/xdm\x00--logout" in x]:
                     return True
                 time.sleep(1)
             else:
