@@ -14,7 +14,7 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-import action
-import desktop
+from . import action
+from . import desktop
 
 section = "desktop"
